/***************************************************************************
 *   Copyright (C) 2005 by Peter Donis                                     *
 *   peterdonis@alum.mit.edu                                               *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/


#include <qpushbutton.h>
#include <qlineedit.h>
#include <kpushbutton.h>
#include <qcheckbox.h>
#include <qcombobox.h>
#include <qspinbox.h>
#include <ktextbrowser.h>
#include "kidserverwidget.h"

kidserverWidget::kidserverWidget(QWidget* parent, const char* name, WFlags fl)
  : kidserverWidgetBase(parent,name,fl)
{
  portval = new QIntValidator(0, 65535, this);
  spinBoxPort->setValidator(portval);

  kPushButtonStop->hide();

  connect(kPushButtonAbout, SIGNAL(clicked()), this, SIGNAL(kPushButtonAbout_clicked()));
  connect(kPushButtonQuit, SIGNAL(clicked()), this, SIGNAL(kPushButtonQuit_clicked()));
  connect(kPushButtonGo, SIGNAL(clicked()), this, SIGNAL(kPushButtonGo_clicked()));
  connect(kPushButtonStop, SIGNAL(clicked()), this, SIGNAL(kPushButtonStop_clicked()));

  connect(checkBoxDNSonly, SIGNAL(toggled(bool)), this, SLOT(checkBoxDNSonly_toggled(bool)));
  connect(checkBoxProtocol, SIGNAL(toggled(bool)), this, SLOT(checkBoxProtocol_toggled(bool)));
  connect(checkBoxPort, SIGNAL(toggled(bool)), this, SLOT(checkBoxPort_toggled(bool)));
  connect(comboBoxProtocol, SIGNAL(activated(int)), this, SLOT(comboBoxProtocol_activated(int)));
  connect(lineEditURL, SIGNAL(returnPressed()), this, SLOT(lineEditURL_returnPressed()));

  lineEditURL->setFocus();
}

kidserverWidget::~kidserverWidget()
{
  disconnect(checkBoxDNSonly, SIGNAL(toggled(bool)), this, SLOT(checkBoxDNSonly_toggled(bool)));
  disconnect(checkBoxProtocol, SIGNAL(toggled(bool)), this, SLOT(checkBoxProtocol_toggled(bool)));
  disconnect(checkBoxPort, SIGNAL(toggled(bool)), this, SLOT(checkBoxPort_toggled(bool)));
  disconnect(comboBoxProtocol, SIGNAL(activated(int)), this, SLOT(comboBoxProtocol_activated(int)));
  disconnect(lineEditURL, SIGNAL(returnPressed()), this, SLOT(lineEditURL_returnPressed()));

  disconnect(kPushButtonAbout, SIGNAL(clicked()), this, SIGNAL(kPushButtonAbout_clicked()));
  disconnect(kPushButtonQuit, SIGNAL(clicked()), this, SIGNAL(kPushButtonQuit_clicked()));
  disconnect(kPushButtonGo, SIGNAL(clicked()), this, SIGNAL(kPushButtonGo_clicked()));
  disconnect(kPushButtonStop, SIGNAL(clicked()), this, SIGNAL(kPushButtonStop_clicked()));

  delete portval;
}

/*$SPECIALIZATION$*/

void kidserverWidget::checkBoxDNSonly_toggled( bool )
{
  enablespecs();
  enableproto();
  enableportnum();
  setportnum();
}

void kidserverWidget::checkBoxProtocol_toggled( bool )
{
  enableproto();
  setportnum();
}

void kidserverWidget::checkBoxPort_toggled( bool )
{
  enableportnum();
  setportnum();
}

void kidserverWidget::comboBoxProtocol_activated( int )
{
  setportnum();
}

void kidserverWidget::lineEditURL_returnPressed()
{
  if ( kPushButtonGo->isEnabled() ) {
    kPushButtonGo->animateClick();
  }
}

// callbacks for main program

void kidserverWidget::lineEditURL_setText( const char * text )
{
  lineEditURL->setText(text);
}

void kidserverWidget::kTextBrowserOutput_output( const char *newtext )
{
  QString temp = kTextBrowserOutput->text();
  temp.append(newtext);

  kTextBrowserOutput->setText(temp);
}

void kidserverWidget::kTextBrowserOutput_clear()
{
  kTextBrowserOutput->setText("");
}

void kidserverWidget::proc_running()
{
  kPushButtonGo->hide();
  kPushButtonGo->setEnabled(FALSE);
  kPushButtonStop->setEnabled(TRUE);
  kPushButtonStop->show();
}

void kidserverWidget::proc_stopped()
{
  kPushButtonStop->hide();
  kPushButtonStop->setEnabled(FALSE);
  kPushButtonGo->setEnabled(TRUE);
  kPushButtonGo->show();
}

// data output for main program

const char * kidserverWidget::URL_text()
{
  return lineEditURL->text();
}

const char * kidserverWidget::protocol_arg()
{
  return comboBoxProtocol->currentText();
}

const char * kidserverWidget::port_arg()
{
  return spinBoxPort->text();
}

bool kidserverWidget::DNS_only()
{
  return checkBoxDNSonly->isChecked();
}

bool kidserverWidget::protocol_set()
{
  return checkBoxProtocol->isChecked();
}

bool kidserverWidget::port_set()
{
  return checkBoxPort->isChecked();
}

// private methods

void kidserverWidget::setportnum()
{
  int portnum = 0;

  if ( !checkBoxPort->isChecked() ) {
    switch ( comboBoxProtocol->currentItem() ) {
      case 0: portnum = 21; break;
      case 1: portnum = 80; break;
      case 2: portnum = 143; break;
      case 3: portnum = 119; break;
      case 4: portnum = 110; break;
      case 5: portnum = 25; break;
    }
    if ( portnum > 0 ) spinBoxPort->setValue(portnum);
  }
}

void kidserverWidget::enableproto()
{
  comboBoxProtocol->setEnabled(checkBoxProtocol->isChecked());
  if ( !comboBoxProtocol->isEnabled() )
  {
    comboBoxProtocol->setCurrentItem(1);
  }
}

void kidserverWidget::enableportnum()
{
  spinBoxPort->setEnabled(checkBoxPort->isChecked());
}

void kidserverWidget::enablespecs()
{
  bool enable = !checkBoxDNSonly->isChecked();
  checkBoxProtocol->setEnabled(enable);
  if ( !enable ) checkBoxProtocol->setChecked(false);
  checkBoxPort->setEnabled(enable);
  if ( !enable ) checkBoxPort->setChecked(false);
}

#include "kidserverwidget.moc"
