/***************************************************************************
 *   Copyright (C) 2005 by Peter Donis                                     *
 *   peterdonis@alum.mit.edu                                               *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/


#include "kidserver.h"
#include <kapplication.h>
#include <kaboutdata.h>
#include <kcmdlineargs.h>
#include <klocale.h>

#define nameoffset 9
static const char *cname = "(C) 2005 Peter A. Donis";
static const char *email = "peterdonis@alum.mit.edu";
static const char *webpage = "http://www.peterdonis.net";

static const char *description =
I18N_NOOP("KIDserver: A graphical interface to the IDserver utility.");

static const char *freetext =
I18N_NOOP("KIDserver provides a graphical interface to the IDserver command-line utility,\n\
which displays information about web servers. The IDserver utility must be installed on\n\
your system for KIDserver to work. IDserver's documentation contains more information\n\
about the utility's functions.");

static const char version[] = "0.4.1";

static KCmdLineOptions options[] =
{
    { "+[URL]", I18N_NOOP( "URL to check" ), 0 },
    KCmdLineLastOption
};

int main(int argc, char **argv)
{
  KAboutData about("kidserver", I18N_NOOP("KIDserver"), version, description,
    KAboutData::License_GPL, cname, freetext, webpage, email);
  about.addAuthor( &cname[nameoffset], 0, email, webpage );
  KCmdLineArgs::init(argc, argv, &about);
  KCmdLineArgs::addCmdLineOptions( options );
  KApplication app;
  kidserver *mainWin = 0;

  if (app.isRestored())
  {
    RESTORE(kidserver(&about, 0));
  }
  else
  {
    // no session.. just start up normally
    KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
  
    // check if URL was passed on the command line
    if ( args->count() > 0 )
    {
      mainWin = new kidserver(&about, args->arg(0));
    }
    else
    {
      mainWin = new kidserver(&about, 0);
    }
    app.setMainWidget( mainWin );
    mainWin->show();

    args->clear();
  }

  // mainWin has WDestructiveClose flag by default, so it will delete itself.
  return app.exec();
}
